# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litepie/mediauser/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litepie/mediauser/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litepie\\Mediauser\\": "packages/litepie/mediauser/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litepie\Mediauser\Providers\MediauserServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Mediauser'  => Litepie\Mediauser\Facades\Mediauser::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litepie\\MediauserTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litepie\Mediauser\Providers\MediauserServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litepie\Mediauser\Providers\MediauserServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litepie\Mediauser\Providers\MediauserServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/mediauser/{modulename}

**User**

    http://path-to-route-folder/user/mediauser/{modulename}

**Public**

    http://path-to-route-folder/mediausers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/mediauser/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/mediauser/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/mediauser/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/mediauser/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/mediauser/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/mediauser/{modulename}/{slug}
    METHOD: GET