<?php

namespace Litepie\Mediauser\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Mediauser\Models\MediaUser;

class MediaUserPolicy
{

    /**
     * Determine if the given user can view the media_user.
     *
     * @param UserPolicy $user
     * @param MediaUser $media_user
     *
     * @return bool
     */
    public function view(UserPolicy $user, MediaUser $media_user)
    {
        if ($user->canDo('mediauser.media_user.view') && $user->isAdmin()) {
            return true;
        }

        return $media_user->user_id == user_id() && $media_user->user_type == user_type();
    }

    /**
     * Determine if the given user can create a media_user.
     *
     * @param UserPolicy $user
     * @param MediaUser $media_user
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('mediauser.media_user.create');
    }

    /**
     * Determine if the given user can update the given media_user.
     *
     * @param UserPolicy $user
     * @param MediaUser $media_user
     *
     * @return bool
     */
    public function update(UserPolicy $user, MediaUser $media_user)
    {
        if ($user->canDo('mediauser.media_user.edit') && $user->isAdmin()) {
            return true;
        }

        return $media_user->user_id == user_id() && $media_user->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given media_user.
     *
     * @param UserPolicy $user
     * @param MediaUser $media_user
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MediaUser $media_user)
    {
        return $media_user->user_id == user_id() && $media_user->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given media_user.
     *
     * @param UserPolicy $user
     * @param MediaUser $media_user
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MediaUser $media_user)
    {
        if ($user->canDo('mediauser.media_user.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given media_user.
     *
     * @param UserPolicy $user
     * @param MediaUser $media_user
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MediaUser $media_user)
    {
        if ($user->canDo('mediauser.media_user.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
