<?php

namespace Litepie\Mediauser\Providers;

use Illuminate\Support\ServiceProvider;

class MediauserServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'mediauser');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'mediauser');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerMediauser();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerMediauser()
    {
        $this->app->bind('mediauser', function($app) {
            return new Mediauser($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Mediauser', 'Lavalite\Mediauser\Facades\Mediauser');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepie.mediauser', function ($app) {
            return $this->app->make('Litepie\Mediauser\Mediauser');
        });

        // Bind User to repository
        $this->app->bind(
            'Litepie\Mediauser\Interfaces\UserRepositoryInterface',
            \Litepie\Mediauser\Repositories\Eloquent\UserRepository::class
        );
        // Bind MediaUser to repository
        $this->app->bind(
            'Litepie\Mediauser\Interfaces\MediaUserRepositoryInterface',
            \Litepie\Mediauser\Repositories\Eloquent\MediaUserRepository::class
        );

        $this->app->register(\Litepie\Mediauser\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepie\Mediauser\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and mediauser's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepie.mediauser'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeMediauser::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepie.mediauser'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepie/mediauser.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/mediauser')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/mediauser')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
