<?php

namespace Litepie\Mediauser\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepie\Mediauser\Models\Mediauser;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepie\Mediauser\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/mediauser/user/*')) {
            Route::bind('user', function ($user) {
                $userrepo = $this->app->make('Litepie\Mediauser\Interfaces\UserRepositoryInterface');
                return $userrepo->findorNew($user);
            });
        }

        if (Request::is('*/mediauser/media_user/*')) {
            Route::bind('media_user', function ($media_user) {
                $media_userrepo = $this->app->make('Litepie\Mediauser\Interfaces\MediaUserRepositoryInterface');
                return $media_userrepo->findorNew($media_user);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
